@@ -20,7 +20,7 @@ package org.apache.skywalking.apm.plugin.spring.mvc.v5.define;
 import org.apache.skywalking.apm.agent.core.plugin.interceptor.enhance.ClassInstanceMethodsEnhancePluginDefine;
 
 public abstract class AbstractSpring5Instrumentation extends ClassInstanceMethodsEnhancePluginDefine {
-    public static final String WITNESS_CLASSES = "org.springframework.web.servlet.resource.HttpResource";
+    public static final String WITNESS_CLASSES = "org.springframework.beans.annotation.AnnotationBeanUtils";
 
     @Override
     protected final String[] witnessClasses() {
